@@ -12,7 +12,7 @@ our @EXPORT = qw(validate_nop_pbb);
 
 our %SPEC;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 $SPEC{validate_nop_pbb} = {
     v => 1.1,
@@ -102,7 +102,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -110,7 +110,7 @@ Business::ID::NOPPBB - Validate Indonesian property tax object number (NOP PBB)
 
 =head1 VERSION
 
-version 0.04
+This document describes version 0.05 of Business::ID::NOPPBB (from Perl distribution Business-ID-NOPPBB), released on 2014-07-22.
 
 =head1 SYNOPSIS
 
@@ -146,10 +146,10 @@ This module has L<Rinci> metadata.
 None exported by default but they are exportable.
 
 
-None are exported by default, but they are exportable.
-
 =head2 validate_nop_pbb(%args) -> [status, msg, result, meta]
 
+Validate (and parse) Indonesian property tax number (NOP PBB).
+
 Indonesian property tax object number, or Nomor Objek Pajak Pajak Bumi dan
 Bangunan, is a number given to a tax object (a piece of land with its
 house/building).
@@ -183,7 +183,32 @@ The input string containing number to check.
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+ (hash)
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Business-ID-NOPPBB>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Business-ID-NOPPBB>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Business-ID-NOPPBB>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
@@ -191,7 +216,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
